/*
DL2 Monitor: ./pa/ip.h
Copyright (C) 2002, Rolf Jger, Ulm (Germany)

See the file README for information on usage and redistribution
of this source code file, and for a DISCLAIMER OF ALL WARRANTIES.
*/

/*----------------------------------------------------------------------------
 * Datalink Monitor (ip): Packet Type ip (local)
 * creates the Pa_Packet object pa_ip: see pa.h for details.
 * The packet type refers to the Internet Protocol, Version 4 (see RFC791).
 *
 * Author: Rolf Jger,Ulm
 *----------------------------------------------------------------------------
 * YYYYMMDD  History 
 * 20020427  follow-tcp,udp,icmp,ip introduced.
 * 20020410  attention to reserved verbose flags.
 * 20020405  selectable fields specified.
 * 20020330  created from scratch
 * $Id: ip.h,v 1.4 2002/04/29 19:31:31 dv Exp $
 *----------------------------------------------------------------------------
*/
# ifndef __IP_H__
# define __IP_H__
# include "pa/pa.h"

static Pa_Config pa_ip_field[] = {
  {"version","V",0},
  {"header-length","HL",1},
  {"service-type","TOS",2},
  {"length","DL",3},
  {"fragment-id","FI",4},
  {"flags","FDM",5},
  {"fragment-offset","FO",6},
  {"time-to-live","TTL",7},
  {"protocol","P",8},
  {"checksum","CS",9},
  {"source-addr","SA",10},
  {"destination-addr","DA",11},
  {"options","O",12},
  {"data","FD",13},
  {"follow-frame","",14},
  {"follow-tcp","",15},
  {"follow-udp","",16},
  {"follow-icmp","",17},
  {"follow-ip","",18},
  {NULL,NULL,-1}
};
const Pa_Packet pa_ip = {"ip",pa_ip_field};

# define IP_Mversion			0x00000001
# define IP_Mheader_length		0x00000002
# define IP_Mservice_type		0x00000004
# define IP_Mlength			0x00000008
# define IP_Mfragment_id		0x00000010
# define IP_Mflags			0x00000020
# define IP_Mfragment_offset		0x00000040
# define IP_Mtime_to_live		0x00000080
# define IP_Mprotocol			0x00000100
# define IP_Mchecksum			0x00000200
# define IP_Msource_addr		0x00000400
# define IP_Mdestination_addr		0x00000800
# define IP_Moptions			0x00001000
# define IP_Mdata			0x00002000
# define IP_Mfollow_frame		0x00004000
# define IP_Mfollow_tcp			0x00008000
# define IP_Mfollow_udp			0x00010000
# define IP_Mfollow_icmp		0x00020000
# define IP_Mfollow_ip			0x00040000
# define IP_Mdefault			PA_VMdefault
# define IP_Mpacket_length		PA_VMpacket_length

# define IP_F(i)			pa_ip_field[i].oname
# define IP_Fversion			IP_F(0)
# define IP_Fheader_length		IP_F(1)
# define IP_Fservice_type		IP_F(2)
# define IP_Flength			IP_F(3)
# define IP_Ffragment_id		IP_F(4)
# define IP_Fflags			IP_F(5)
# define IP_Ffragment_offset		IP_F(6)
# define IP_Ftime_to_live		IP_F(7)
# define IP_Fprotocol			IP_F(8)
# define IP_Fchecksum			IP_F(9)
# define IP_Fsource_addr		IP_F(10)
# define IP_Fdestination_addr		IP_F(11)
# define IP_Foptions			IP_F(12)
# define IP_Fdata			IP_F(13)
# define IP_Ffollow_frame		IP_F(14)
# define IP_Ffollow_tcp			IP_F(15)
# define IP_Ffollow_udp			IP_F(16)
# define IP_Ffollow_icmp		IP_F(17)
# define IP_Ffollow_ip			IP_F(18)
# define IP_Fpacket_length		PA_VFpacket_length
//#undef IP_F

# endif /*__IP_H__*/
